@@ -25,11 +25,11 @@ from .literals import (
     KafkaVersionStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -571,7 +571,7 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "Description": str,
         "Revision": int,
-        "ServerProperties": bytes,
+        "ServerProperties": StreamingBody,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
